BitValue

Struct BitValue 

pub struct BitValue<const BITS: u32>(pub u32);
A wrapper for restricted bit-sized value with debug assert.

The idea is to make it validate in debug only, in the release it is zero-cost, and the caller is responsible for the validity of values.

Tuple Fields

0: u32

Implementations

Source

impl<const BITS: u32> BitValue<BITS>

pub const fn new_u32(nested: u32) -> Self

pub const fn new_i32(nested: i32) -> Self

pub const fn into_inner(self) -> u32