pub struct BitValue<const BITS: u32>(pub u32);Expand description
A wrapper for restricted bit-sized value with debug assert.
The idea is to make it validate in debug only, in the release it is zero-cost, and the caller is responsible for the validity of values.
Tuple Fields
0: u32Implementations